import { useState } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Progress } from "@/components/ui/progress";
import { Download, Loader2 } from "lucide-react";
import { useMutation, useQueryClient } from "@tanstack/react-query";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import AdBanner from "@/components/ads/AdBanner";

interface DownloadResponse {
  success: boolean;
  video: {
    title: string;
    creator: string;
    downloadUrl: string;
    thumbnailUrl?: string;
    quality: string;
    format: string;
  };
  downloadId: number;
}

export default function HeroSection() {
  const [videoUrl, setVideoUrl] = useState("");
  const [downloadProgress, setDownloadProgress] = useState(0);
  const { toast } = useToast();
  const queryClient = useQueryClient();

  const downloadMutation = useMutation({
    mutationFn: async (url: string) => {
      const response = await apiRequest<DownloadResponse>({
        url: "/api/download",
        method: "POST",
        body: JSON.stringify({ videoUrl: url }),
      });
      return response;
    },
    onSuccess: (data) => {
      if (data.success) {
        // Trigger download
        const link = document.createElement("a");
        link.href = data.video.downloadUrl;
        link.download = `${data.video.title}.${data.video.format}`;
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);

        toast({
          title: "Download Started!",
          description: `${data.video.title} by ${data.video.creator}`,
        });

        // Invalidate queries to refresh data
        queryClient.invalidateQueries({ queryKey: ["/api/download-history"] });
        queryClient.invalidateQueries({ queryKey: ["/api/stats"] });
      }
    },
    onError: (error: Error) => {
      toast({
        title: "Download Failed",
        description: error.message || "The video download service is temporarily unavailable. Please try again later.",
        variant: "destructive",
      });
    },
  });

  const handleDownload = async () => {
    if (!videoUrl.trim()) {
      toast({
        title: "Please enter a URL",
        description: "Please paste a TikTok video URL to download",
        variant: "destructive",
      });
      return;
    }

    // Validate TikTok URL - accept both regular and shortened URLs
    const isValidTikTokUrl = videoUrl.includes('tiktok.com') || 
                             videoUrl.includes('vt.tiktok.com') ||
                             videoUrl.includes('vm.tiktok.com') ||
                             videoUrl.includes('m.tiktok.com');
    
    if (!isValidTikTokUrl) {
      toast({
        title: "Invalid URL",
        description: "Please enter a valid TikTok video URL",
        variant: "destructive",
      });
      return;
    }

    // Reset progress
    setDownloadProgress(0);

    // Simulate progress for better UX
    setDownloadProgress(10);
    const progressInterval = setInterval(() => {
      setDownloadProgress(prev => {
        if (prev >= 90) {
          clearInterval(progressInterval);
          return prev;
        }
        return prev + 10;
      });
    }, 200);

    try {
      await downloadMutation.mutateAsync(videoUrl);
      setDownloadProgress(100);
    } catch (error) {
      clearInterval(progressInterval);
      setDownloadProgress(0);
    }
  };

  return (
    <section id="home" className="py-12 sm:py-20 px-4">
      <div className="container mx-auto text-center">
        <h1 className="text-3xl sm:text-4xl md:text-6xl font-bold text-white mb-4 sm:mb-6">
          Download TikTok Videos
          <span className="block text-transparent bg-clip-text bg-gradient-to-r from-white to-cyan-200">
            Without Watermark
          </span>
        </h1>
        
        <p className="text-lg sm:text-xl text-white/90 mb-6 sm:mb-8 max-w-2xl mx-auto">
          Fast, free, and secure TikTok video downloader. Save your favorite TikTok videos in high quality without watermarks.
        </p>
        
        {/* Top Banner Ad - Show mobile ad here since header ad is hidden */}
        <div className="mb-6 sm:mb-8">
          <AdBanner 
            adSlot="1234567890" 
            adFormat="horizontal"
            className="max-w-4xl mx-auto px-4"
            style={{ minHeight: '50px' }}
          />
        </div>
        
        <div className="max-w-2xl mx-auto">
          <div className="bg-white/10 backdrop-blur-md rounded-3xl p-4 sm:p-8 border border-white/20 shadow-2xl">
            <div className="flex flex-col md:flex-row gap-4">
              <div className="flex-1">
                <Input
                  type="url"
                  placeholder="Paste TikTok video URL here..."
                  value={videoUrl}
                  onChange={(e) => setVideoUrl(e.target.value)}
                  className="px-6 py-4 bg-white/90 border-white/30 rounded-xl text-lg h-auto"
                  disabled={downloadMutation.isPending}
                />
              </div>
              <Button
                onClick={handleDownload}
                disabled={downloadMutation.isPending}
                className="bg-gradient-to-r from-pink-500 to-purple-500 hover:from-pink-600 hover:to-purple-600 text-white px-8 py-4 rounded-xl font-semibold text-lg h-auto"
              >
                {downloadMutation.isPending ? (
                  <>
                    <Loader2 className="mr-2 h-5 w-5 animate-spin" />
                    Downloading...
                  </>
                ) : (
                  <>
                    <Download className="mr-2 h-5 w-5" />
                    Download
                  </>
                )}
              </Button>
            </div>
            
            {downloadMutation.isPending && (
              <div className="mt-6">
                <Progress value={downloadProgress} className="w-full" />
                <p className="text-sm text-white/80 mt-2">
                  {downloadProgress < 100 ? "Downloading your video..." : "Processing complete!"}
                </p>
              </div>
            )}
          </div>
        </div>
        
        {/* After download form ad - mobile-friendly */}
        <div className="mt-6 sm:mt-8">
          <AdBanner 
            adSlot="1234567891" 
            adFormat="rectangle"
            className="max-w-2xl mx-auto px-4"
            style={{ minHeight: '200px' }}
          />
        </div>
      </div>
    </section>
  );
}